@@ -23,6 +23,7 @@ import (
 	"crypto/x509"
 	"fmt"
 	"os"
+	"time"
 
 	"github.com/apache/skywalking-satellite/plugins/client/grpc/lb"
 
@@ -52,24 +53,39 @@ func (c *Client) loadConfig() (*[]grpc.DialOption, error) {
 		authHeader = metadata.New(map[string]string{"Authentication": c.Authentication})
 	}
 
+	unaryRequestTimeout, err := time.ParseDuration(c.Timeout.Unary)
+	if err != nil {
+		return nil, fmt.Errorf("cannot parse the unary request timeout: %v", err)
+	}
+	streamRequestTimeout, err := time.ParseDuration(c.Timeout.Stream)
+	if err != nil {
+		return nil, fmt.Errorf("cannot parse the stream request timeout: %v", err)
+	}
+
 	// append auth or report error
 	options = append(options, grpc.WithStreamInterceptor(func(ctx context.Context, desc *grpc.StreamDesc,
 		cc *grpc.ClientConn, method string, streamer grpc.Streamer, opts ...grpc.CallOption) (grpc.ClientStream, error) {
 		if authHeader != nil {
 			ctx = metadata.NewOutgoingContext(ctx, authHeader)
 		}
-		clientStream, err := streamer(ctx, desc, cc, method, opts...)
+		timeout, timeoutFunc := context.WithTimeout(ctx, streamRequestTimeout)
+		clientStream, err := streamer(timeout, desc, cc, method, opts...)
 		if err != nil {
+			timeoutFunc()
 			c.reportError(err)
+			return nil, err
 		}
-		return clientStream, err
+		streamWrapper := &timeoutClientStream{clientStream, timeoutFunc}
+		return streamWrapper, err
 	}))
 	grpc.WithUnaryInterceptor(func(ctx context.Context, method string, req, reply interface{},
 		cc *grpc.ClientConn, invoker grpc.UnaryInvoker, opts ...grpc.CallOption) error {
 		if authHeader != nil {
 			ctx = metadata.NewOutgoingContext(ctx, authHeader)
 		}
-		err := invoker(ctx, method, req, reply, cc, opts...)
+		timeout, timeoutFunc := context.WithTimeout(ctx, unaryRequestTimeout)
+		defer timeoutFunc()
+		err := invoker(timeout, method, req, reply, cc, opts...)
 		if err != nil {
 			c.reportError(err)
 		}
@@ -82,6 +98,16 @@ func (c *Client) loadConfig() (*[]grpc.DialOption, error) {
 	return &options, nil
 }
 
+type timeoutClientStream struct {
+	grpc.ClientStream
+	timeoutFunc context.CancelFunc
+}
+
+func (t *timeoutClientStream) RecvMsg(m interface{}) error {
+	defer t.timeoutFunc()
+	return t.ClientStream.RecvMsg(m)
+}
+
 // configTLS loads and parse the TLS configs.
 func (c *Client) configTLS() (tc *tls.Config, tlsErr error) {
 	if err := checkTLSFile(c.CaPemPath); err != nil {
