@@ -30,9 +30,11 @@ var rs = []GrpcResolver{
 }
 
 type ServerFinderConfig struct {
-	FinderType       string            `mapstructure:"finder_type"`       // The gRPC server address finder type, support "static" and "kubernetes"
-	ServerAddr       string            `mapstructure:"server_addr"`       // The gRPC server address
-	KubernetesConfig *KubernetesConfig `mapstructure:"kubernetes_config"` // The kubernetes config to lookup addresses
+	FinderType string `mapstructure:"finder_type"` // The gRPC server address finder type, support "static" and "kubernetes"
+	// The gRPC server address, only works for "static" address finder
+	ServerAddr string `mapstructure:"server_addr"`
+	// The kubernetes config to lookup addresses, only works for "kubernetes" address finder
+	KubernetesConfig *KubernetesConfig `mapstructure:"kubernetes_config"`
 }
 
 type GrpcResolver interface {
