@@ -29,7 +29,10 @@ import (
 	"github.com/apache/skywalking-satellite/plugins/client/api"
 )
 
-const Name = "kafka-client"
+const (
+	Name     = "kafka-client"
+	ShowName = "Kafka Client"
+)
 
 type Client struct {
 	config.CommonFields
@@ -62,6 +65,10 @@ func (c *Client) Name() string {
 	return Name
 }
 
+func (c *Client) ShowName() string {
+	return ShowName
+}
+
 func (c *Client) Description() string {
 	return "The Kafka client is a sharing plugin to keep connection with the Kafka brokers and delivery the data to it."
 }
